what.models.detection.frcnn.meter.meter API documentation

# what.models.detection.frcnn.meter.meter

View Source

     1class Meter(object):
     2    '''Meters provide a way to keep track of important statistics in an online manner.
     3
     4    This class is abstract, but provides a standard interface for all meters to follow.
     5
     6    '''
     7
     8    def reset(self):
     9        '''Resets the meter to default settings.'''
    10        pass
    11
    12    def add(self, value):
    13        '''Log a new value to the meter
    14
    15        Args:
    16            value: Next restult to include.
    17
    18        '''
    19        pass
    20
    21    def value(self):
    22        '''Get the value of the meter in the current state.'''
    23        pass

class Meter: View Source

     3class Meter(object):
     4    '''Meters provide a way to keep track of important statistics in an online manner.
     5
     6    This class is abstract, but provides a standard interface for all meters to follow.
     7
     8    '''
     9
    10    def reset(self):
    11        '''Resets the meter to default settings.'''
    12        pass
    13
    14    def add(self, value):
    15        '''Log a new value to the meter
    16
    17        Args:
    18            value: Next restult to include.
    19
    20        '''
    21        pass
    22
    23    def value(self):
    24        '''Get the value of the meter in the current state.'''
    25        pass

Meters provide a way to keep track of important statistics in an online manner.

This class is abstract, but provides a standard interface for all meters to follow.

def reset(self): View Source

    10    def reset(self):
    11        '''Resets the meter to default settings.'''
    12        pass

Resets the meter to default settings.

def add(self, value): View Source

    14    def add(self, value):
    15        '''Log a new value to the meter
    16
    17        Args:
    18            value: Next restult to include.
    19
    20        '''
    21        pass

Log a new value to the meter

Args: value: Next restult to include.

def value(self): View Source

    23    def value(self):
    24        '''Get the value of the meter in the current state.'''
    25        pass

Get the value of the meter in the current state.